@@ -10,6 +10,7 @@ from aporia.as_code.stack import Stack
 # Consts
 from aporia.sdk.data_sources import DataSourceType
 from aporia.sdk.datasets import DatasetType, SortOrder
+from aporia.sdk.metrics import MetricType
 from aporia.sdk.models import ModelAggregationPeriod, ModelColor, ModelIcon, ModelType
 from aporia.sdk.monitors import (
     AverageMethod,
@@ -17,7 +18,6 @@ from aporia.sdk.monitors import (
     DetectionMethod,
     FocalConfiguration,
     MessagingIntegrationType,
-    MetricType,
     MonitorType,
     PeriodType,
     SEGMENT_ID_ALL_DATA,
