@@ -8,7 +8,7 @@ from aporia.as_code.resources.segment import Segment
 from aporia.as_code.resources.version import Version
 from aporia.sdk.client import Client
 from aporia.sdk.models import Model as _Model
-from aporia.sdk.models import ModelColor, ModelIcon, ModelType, NoOwner, ModelAggregationPeriod
+from aporia.sdk.models import ModelAggregationPeriod, ModelColor, ModelIcon, ModelType, NoOwner
 
 
 class Model(BaseResource):
