@@ -14,12 +14,12 @@ from aporia.sdk.monitors import (
     DetectionMethod,
     FocalConfiguration,
     MetricType,
-    PeriodType,
 )
 from aporia.sdk.monitors import Monitor as _Monitor
 from aporia.sdk.monitors import (
     MonitorConfiguration,
     MonitorType,
+    PeriodType,
     SegmentIdentification,
     Severity,
     ThresholdConfiguration,
@@ -299,5 +299,8 @@ class Monitor(BaseResource):
         if self._args["is_active"] != resource_data["is_active"]:
             diffs["is_active"] = (resource_data["is_active"], self._args["is_active"])
         if self._args["configuration"].to_dict() != resource_data["configuration"]:
-            diffs["configuration"] = (resource_data["configuration"], self._args["configuration"].to_dict())
+            diffs["configuration"] = (
+                resource_data["configuration"],
+                self._args["configuration"].to_dict(),
+            )
         return diffs
