@@ -44,11 +44,16 @@ class Segment(BaseResource):
 
         if "terms" in self._args.keys():
             values = [term[1] for term in self._args["terms"]]
-        extended_data = resource_data.get('extended_data')
-        is_custom_segment = extended_data.get('is_custom_segment') if extended_data else 'terms' in self._args.keys()
+        extended_data = resource_data.get("extended_data")
+        is_custom_segment = (
+            extended_data.get("is_custom_segment")
+            if extended_data
+            else "terms" in self._args.keys()
+        )
         if all(
             [
-                (not is_custom_segment) or (self._args.get("terms") == resource_data["terms_values"]),
+                (not is_custom_segment)
+                or (self._args.get("terms") == resource_data["terms_values"]),
                 self._args.get("field_name") == resource_field_name,
                 values == resource_data["values"],
                 self._args["name"] == resource_data["name"],
@@ -72,14 +77,14 @@ class Segment(BaseResource):
     def create(self, client: Client) -> Tuple[str, Dict]:
         segment = _Segment.create(client=client, **self._args)
         saved_data = segment.raw_data.copy()
-        saved_data['extended_data'] = segment.get_extended_data()
+        saved_data["extended_data"] = segment.get_extended_data()
         return segment.id, saved_data
 
     @classmethod
     def read(cls, client: Client, id: str) -> Dict:
         segment = _Segment.read(client=client, id=id)
         read_data = segment.raw_data.copy()
-        read_data['extended_data'] = segment.get_extended_data()
+        read_data["extended_data"] = segment.get_extended_data()
         return read_data
 
     def update(self, client: Client, id: str) -> Dict:
@@ -95,4 +100,4 @@ class Segment(BaseResource):
         diffs = {}
         if self._args["name"] != resource_data["name"]:
             diffs["name"] = (resource_data["name"], self._args["name"])
-        return diffs
\ No newline at end of file
+        return diffs
