@@ -9,7 +9,13 @@ import string
 import traceback
 from typing import Any, Dict, List, Optional, Tuple
 
-from aporia.as_code.resources.base import BaseResource, CompareStatus, NonDeletableResourceException
+from requests import Session
+
+from aporia.as_code.resources.base import (
+    BaseResource,
+    CompareStatus,
+    NonDeletableResourceException,
+)
 from aporia.as_code.resources.custom_metrics import CustomMetric
 from aporia.as_code.resources.data_source import DataSource
 from aporia.as_code.resources.dataset import Dataset
@@ -32,7 +38,11 @@ from aporia.sdk.monitors import (
     MessagingIntegrationType,
 )
 from aporia.sdk.monitors import Monitor as SDKMonitor
-from aporia.sdk.monitors import MonitorType, parse_monitor_configuration, PreConditionType
+from aporia.sdk.monitors import (
+    MonitorType,
+    parse_monitor_configuration,
+    PreConditionType,
+)
 from aporia.sdk.segments import Segment as SDKSegment
 from aporia.sdk.versions import Version as SDKVersion
 
@@ -81,14 +91,23 @@ class Stack:
         account: str,
         workspace: str = "default-workspace",
         base_url: str = "https://platform.aporia.com",
+        requests_session: Optional[Session] = None,
     ):
         self._resources: OrderedDict[str, Resource] = OrderedDict()
         self._output = None
         self._base_url = base_url
-        self._client = Client(base_url=f"{base_url}/api/v1/{account}/{workspace}", token=token)
+        self._client = Client(
+            base_url=f"{base_url}/api/v1/{account}/{workspace}",
+            token=token,
+            requests_session=requests_session,
+        )
         self._delete_resources: OrderedDict[str, BaseResource] = OrderedDict()
         self._aporia_api = Aporia(
-            token=token, account_name=account, workspace_name=workspace, base_url=base_url
+            token=token,
+            account_name=account,
+            workspace_name=workspace,
+            base_url=base_url,
+            requests_session=requests_session,
         )
 
     def add(self, resource: BaseResource, depth=0, prefix=None):
@@ -102,7 +121,11 @@ class Stack:
         )
         if hasattr(resource, "sub_resources"):
             for sub_resource, _ in resource.sub_resources:
-                self.add(sub_resource, depth=depth + 1, prefix=f"{prefix or ''}{resource.name}/")
+                self.add(
+                    sub_resource,
+                    depth=depth + 1,
+                    prefix=f"{prefix or ''}{resource.name}/",
+                )
 
     def _call_argsetters(self, resource, resource_data):
         if hasattr(resource, "sub_resources"):
@@ -318,11 +341,12 @@ class Stack:
             code += ")"
             return code, self.__resource_name_to_python_name(resource.name)
         elif isinstance(resource, SDKCustomMetric):
-            return f'''{self.__resource_name_to_python_name(resource.name)} = aporia.CustomMetric(
+            return (
+                f'''{self.__resource_name_to_python_name(resource.name)} = aporia.CustomMetric(
     "{resource.name}",
     code="""{resource.raw_data["code"]}""",
-)''', self.__resource_name_to_python_name(
-                resource.name
+)''',
+                self.__resource_name_to_python_name(resource.name),
             )
         elif isinstance(resource, SDKDataset):
             schema = resource.raw_data["schema"]
@@ -423,7 +447,10 @@ class Stack:
                 code += f"\tbaseline=aporia.BaselineConfiguration(**{parsed_config.baseline.to_dict()}),\n"
 
             # Metric Configuration
-            if resource.type in [MonitorType.PERFORMANCE_DEGRADATION, MonitorType.METRIC_CHANGE]:
+            if resource.type in [
+                MonitorType.PERFORMANCE_DEGRADATION,
+                MonitorType.METRIC_CHANGE,
+            ]:
                 code += f"\tmetric=aporia.MetricType.{parsed_config.metric.type.name},\n"
             metric_config = parsed_config.metric
             if metric_config.id is not None:
@@ -436,6 +463,8 @@ class Stack:
                 code += f"\taverage_method=aporia.AverageMethod.{metric_config.average.name},\n"
             if metric_config.metricAtK is not None:
                 code += f"\tk={metric_config.metricAtK},\n"
+            if metric_config.quantile is not None:
+                code += f"\tquantile={metric_config.quantile},\n"
             if metric_config.threshold is not None:
                 code += f"\tprediction_threshold={metric_config.threshold},\n"
             if metric_config.metricPerClass is not None:
@@ -540,7 +569,8 @@ class Stack:
             code += ")"
             return code, self.__resource_name_to_python_name(resource.name)
         elif isinstance(resource, SDKModel):
-            return f"""{self.__resource_name_to_python_name(resource.name)} = aporia.Model(
+            return (
+                f"""{self.__resource_name_to_python_name(resource.name)} = aporia.Model(
     "{resource.name}",
     type=aporia.ModelType.{resource.type.name},
     icon=aporia.ModelIcon.{resource.icon.name},
@@ -549,8 +579,8 @@ class Stack:
     segments=[],
     custom_metrics=[],
     monitors=[],
-)""", self.__resource_name_to_python_name(
-                resource.name
+)""",
+                self.__resource_name_to_python_name(resource.name),
             )
         raise TypeError(f"Unsupported type: {type(resource).__name__})")
 
