@@ -1,5 +1,7 @@
 from typing import Any, Dict, List, Optional, Union
 
+from requests import Session
+
 from aporia.sdk.base import BaseAporiaResource
 from aporia.sdk.client import Client
 from aporia.sdk.data_sources import DataSource, DataSourceType
@@ -16,15 +18,27 @@ class Aporia:
         base_url: str = "https://platform.aporia.com",
         debug: bool = False,
         delete_on_failure: bool = False,
+        requests_session: Optional[Session] = None,
     ):
         self._assert_workspace(
-            base_url=base_url, token=token, account=account_name, workspace=workspace_name
+            base_url=base_url,
+            token=token,
+            account=account_name,
+            workspace=workspace_name,
+            requests_session=requests_session,
         )
         self.client = Client(
-            base_url=f"{base_url}/api/v1/{account_name}/{workspace_name}", token=token, debug=debug
+            base_url=f"{base_url}/api/v1/{account_name}/{workspace_name}",
+            token=token,
+            debug=debug,
+            requests_session=requests_session,
         )
         self.metrics_client = AporiaMetrics(
-            token=token, account_name=account_name, workspace_name=workspace_name, base_url=base_url
+            token=token,
+            account_name=account_name,
+            workspace_name=workspace_name,
+            base_url=base_url,
+            requests_session=requests_session,
         )
         self.delete_on_failure = delete_on_failure
         self._created_resources: List[BaseAporiaResource] = []
@@ -51,7 +65,10 @@ class Aporia:
         return model
 
     def create_data_source(
-        self, name: str, data_source_type: DataSourceType, connection_data: Dict[str, Any]
+        self,
+        name: str,
+        data_source_type: DataSourceType,
+        connection_data: Dict[str, Any],
     ) -> DataSource:
         data_source = DataSource.create(
             client=self.client,
@@ -85,8 +102,19 @@ class Aporia:
             if self.delete_on_failure:
                 self.delete()
 
-    def _assert_workspace(self, base_url: str, token: str, account: str, workspace: str):
-        client = Client(base_url=base_url, token=token)
+    def _assert_workspace(
+        self,
+        base_url: str,
+        token: str,
+        account: str,
+        workspace: str,
+        requests_session: Optional[Session] = None,
+    ):
+        client = Client(
+            base_url=base_url,
+            token=token,
+            requests_session=requests_session,
+        )
         response = client.send_request(
             f"/v1/identity-service/accounts/{account}/workspaces/{workspace}", "GET"
         )
