@@ -9,7 +9,6 @@ class EntityNotFoundException(Exception):
 
 
 class BackendRuntimeError(Exception):
-
     status_code: int
     body: Union[str, dict]
 
@@ -20,10 +19,21 @@ class BackendRuntimeError(Exception):
 
 
 class Client:
-    def __init__(self, base_url: str, token: str, debug: bool = False):
+    def __init__(
+        self,
+        base_url: str,
+        token: str,
+        debug: bool = False,
+        requests_session: Optional[requests.Session] = None,
+    ):
         self.base_url = base_url
         self.token = token
         self.debug = debug
+        if requests_session is None:
+            self._session = requests.Session()
+        else:
+            self._session = requests_session
+        # Not setting Authorization header in session in case it's shared between multiple clients
 
     def send_request(
         self,
@@ -45,7 +55,7 @@ class Client:
         if self.debug:
             print(f"{method} {target_url}, ({data})", end=" -> ")
 
-        response = requests.request(
+        response = self._session.request(
             method=method,
             url=target_url,
             json=data,
