@@ -50,7 +50,7 @@ class CustomMetric(BaseAporiaResource):
 
     def update(self, **kwargs):
         response = self.client.send_request(
-            f"/custom-metrics/{self.id}",
+            f"/metrics/custom-metrics/{self.id}",
             "PUT",
             {"syntax": "aporia", **kwargs},
             url_search_replace=("/api/v1/", "/v1/crud-service/"),
