@@ -9,6 +9,8 @@ from aporia.sdk.widgets.base import FixedTimeframe, WidgetType
 from aporia.sdk.widgets.data_health_table_widget import DataHealthTableWidget
 from aporia.sdk.widgets.distribution_widget import DistributionWidget
 from aporia.sdk.widgets.histogram_over_time_widget import HistogramOverTimeWidget
+from aporia.sdk.widgets.metric_by_segment_widget import MetricBySegmentWidget
+from aporia.sdk.widgets.metric_correlation_widget import MetricCorrelationWidget
 from aporia.sdk.widgets.metric_widget import MetricWidget
 from aporia.sdk.widgets.text_widget import TextWidget
 from aporia.sdk.widgets.timeseries_widget import TimeSeriesWidget
@@ -18,6 +20,9 @@ ALLOWED_RELATIVE_TIMEFRAMES = ["1h", "4h", "1d", "2d", "1w", "2w", "1M", "2M", "
 
 class DashboardGlobalFilters(BaseModel):
     timeframe: Union[str, FixedTimeframe]
+    version_id: Optional[str] = None
+    data_segment_id: Optional[str] = None
+    data_segment_value: Optional[Any] = None
 
     @validator("timeframe")
     def _validate_timeframe(cls, value, values):
@@ -28,6 +33,9 @@ class DashboardGlobalFilters(BaseModel):
                 )
         return value
 
+    def dict(self, *args, **kwargs):
+        return {k: v for k, v in super().dict(*args, **kwargs).items() if v is not None}
+
 
 Widget = Union[
     TextWidget,
@@ -36,6 +44,8 @@ Widget = Union[
     HistogramOverTimeWidget,
     MetricWidget,
     TimeSeriesWidget,
+    MetricBySegmentWidget,
+    MetricCorrelationWidget,
 ]
 
 WIDGET_TYPE_TO_CONFIG_CLASS = {
@@ -45,6 +55,8 @@ WIDGET_TYPE_TO_CONFIG_CLASS = {
     WidgetType.TIME_SERIES: TimeSeriesWidget,
     WidgetType.TIME_SERIES_HISTOGRAM: HistogramOverTimeWidget,
     WidgetType.ANOMALY_TABLE: DataHealthTableWidget,
+    WidgetType.METRIC_BY_SEGMENT: MetricBySegmentWidget,
+    WidgetType.METRIC_CORRELATION: MetricCorrelationWidget,
 }
 
 
@@ -83,7 +95,7 @@ def dashboard_widgets_pre_validator(value: Any, values: Dict[str, Any]) -> List[
             raise ValueError("Received widget with no type")
 
         if widget_configuration["type"] not in WIDGET_TYPE_TO_CONFIG_CLASS:
-            raise ValueError(f"Unsupported widget type {values['type']}")
+            raise ValueError(f"Unsupported widget type {widget_configuration['type']}")
 
         if not isinstance(widget_configuration, dict):
             raise ValueError("expected a dict containing data source configuration")
@@ -101,18 +113,18 @@ class Dashboard(BaseAporiaResource):
 
     def __update_members(self, data: Dict):
         self.id = data["id"]
-        self.name = data["name"]
-        self.description = data["description"]
+        self.name: str = data["name"]
+        self.description: str = data["description"]
         self.definition = DashboardConfiguration(**data["definition"])
+        self.model_id: Optional[str] = data.get("model_id")
         self.raw_data = data
 
     @classmethod
     def get_all(cls, client: Client, model_id: Optional[str] = None) -> List["Dashboard"]:
         response = client.send_request(
-            f"/dashboards",
+            "/dashboards",
             "GET",
             params={"model_id": model_id} if model_id is not None else None,
-            url_search_replace=("/api/v1/", "/v1/crud-service/"),
         )
 
         client.assert_response(response)
@@ -134,13 +146,11 @@ class Dashboard(BaseAporiaResource):
             "POST",
             {
                 "name": name,
-                # TODO: Add only if not None
                 "description": description,
                 "model_id": model_id,
                 "definition": definition.dict(),
                 "owner": owner,
             },
-            url_search_replace=("/api/v1/", "/v1/crud-service/"),
         )
 
         client.assert_response(response)
@@ -152,7 +162,6 @@ class Dashboard(BaseAporiaResource):
         response = client.send_request(
             f"/dashboards/{id}",
             "GET",
-            url_search_replace=("/api/v1/", "/v1/crud-service/"),
         )
         client.assert_response(response)
         return cls(client=client, data=response.json())
@@ -176,7 +185,6 @@ class Dashboard(BaseAporiaResource):
             f"/dashboards/{self.id}",
             "PUT",
             args,
-            url_search_replace=("/api/v1/", "/v1/crud-service/"),
         )
         self.client.assert_response(response)
         self.__update_members(response.json())
