@@ -16,6 +16,7 @@ class FieldType(str, Enum):
     ARRAY = "array"
     EMBEDDING = "embedding"
     IMAGE_URL = "image_url"
+    NUMERIC_ARRAY = "numeric_array"
 
 
 class FieldGroup(str, Enum):
@@ -49,7 +50,7 @@ class Field(BaseModel):
     @classmethod
     def get_model_fields(cls, client: Client, model_id: str) -> List["Field"]:
         response = client.send_request(
-            f"/fields",
+            "/fields",
             "GET",
             params={"model_id": model_id},
             url_search_replace=("/api/v1/", "/v1/crud-service/"),
