@@ -3,6 +3,7 @@ from enum import Enum
 from typing import Any, Dict, List, Optional, Union
 
 from pydantic import BaseModel
+from requests import Session
 
 from aporia.sdk.client import Client
 from aporia.sdk.datasets import DatasetType
@@ -51,6 +52,7 @@ class MetricType(str, Enum):
     TN_COUNT_PER_CLASS = "tn_count_per_class"
     FP_COUNT_PER_CLASS = "fp_count_per_class"
     FN_COUNT_PER_CLASS = "fn_count_per_class"
+    QUANTILE = "quantile"
     # Non-aggregable metrics
     AUUC = "auuc"
     # None-Dashboard metrics
@@ -159,9 +161,12 @@ class AporiaMetrics:
         account_name: str,
         base_url: str = "https://platform.aporia.com",
         workspace_name: str = "default-workspace",
+        requests_session: Optional[Session] = None,
     ) -> Dict:
         self.client = Client(
-            base_url=f"{base_url}/api/v1/{account_name}/{workspace_name}", token=token
+            base_url=f"{base_url}/api/v1/{account_name}/{workspace_name}",
+            token=token,
+            requests_session=requests_session,
         )
 
     def query(
@@ -226,6 +231,8 @@ class AporiaMetrics:
                 metric_parameters["k"] = metric.k
             if metric.threshold is not None:
                 metric_parameters["threshold"] = metric.threshold
+            if metric.quantile is not None:
+                metric_parameters["quantile"] = metric.quantile
             if metric.custom_metric_id is not None:
                 metric_parameters["id"] = metric.custom_metric_id
             if metric.value is not None:
