@@ -185,6 +185,7 @@ class MetricConfiguration(BaseModel):
     threshold: Optional[float] = None
     metricPerClass: Optional[Any] = None
     average: Optional[AverageMethod] = None
+    quantile: Optional[float] = None
     # TODO: Maybe add class for Aporia metrics
 
     # TODO: Add validators for params by metric types
@@ -211,6 +212,8 @@ class MetricConfiguration(BaseModel):
             result["metricPerClass"] = self.metricPerClass
         if self.average is not None:
             result["average"] = self.average.value
+        if self.quantile is not None:
+            result["quantile"] = self.quantile
 
         return result
 
@@ -1055,6 +1058,7 @@ _MONITOR_PARAMETERS = {
                 threshold=kw["threshold"],
                 metricPerClass=kw["prediction_class"],
                 average=kw["average_method"],
+                quantile=kw["quantile"],
             ),
             description_builder=lambda **kw: (
                 "An anomaly in the value of the <b>'{metric}'</b> "
@@ -1078,6 +1082,7 @@ _MONITOR_PARAMETERS = {
                 threshold=kw["threshold"],
                 metricPerClass=kw["prediction_class"],
                 average=kw["average_method"],
+                quantile=kw["quantile"],
             ),
             description_builder=lambda **kw: (
                 "An anomaly in the value of the <b>'{metric}'</b> "
@@ -1104,6 +1109,7 @@ _MONITOR_PARAMETERS = {
                 threshold=kw["threshold"],
                 metricPerClass=kw["prediction_class"],
                 average=kw["average_method"],
+                quantile=kw["quantile"],
             ),
             description_builder=lambda **kw: (
                 "An anomaly in the value of the <b>'{metric}'</b> "
@@ -1128,6 +1134,7 @@ _MONITOR_PARAMETERS = {
                 threshold=kw["threshold"],
                 metricPerClass=kw["prediction_class"],
                 average=kw["average_method"],
+                quantile=kw["quantile"],
             ),
             description_builder=lambda **kw: (
                 "An anomaly in the value of the <b>'{metric}'</b> "
@@ -1154,6 +1161,7 @@ _MONITOR_PARAMETERS = {
                 threshold=kw["threshold"],
                 metricPerClass=kw["prediction_class"],
                 average=kw["average_method"],
+                quantile=kw["quantile"],
             ),
             description_builder=lambda **kw: (
                 "An anomaly in the value of the <b>'{metric}'</b> "
@@ -1182,6 +1190,7 @@ _MONITOR_PARAMETERS = {
                 threshold=kw["threshold"],
                 metricPerClass=kw["prediction_class"],
                 average=kw["average_method"],
+                quantile=kw["quantile"],
             ),
             description_builder=lambda **kw: (
                 "An anomaly in the value of the <b>'{metric}'</b> "
@@ -1205,6 +1214,7 @@ _MONITOR_PARAMETERS = {
                 threshold=kw["threshold"],
                 metricPerClass=kw["prediction_class"],
                 average=kw["average_method"],
+                quantile=kw["quantile"],
             ),
             description_builder=lambda **kw: (
                 "An anomaly in the value of the <b>'{metric}'</b> "
@@ -1231,6 +1241,7 @@ _MONITOR_PARAMETERS = {
                 threshold=kw["threshold"],
                 metricPerClass=kw["prediction_class"],
                 average=kw["average_method"],
+                quantile=kw["quantile"],
             ),
             description_builder=lambda **kw: (
                 "An anomaly in the value of the <b>'{metric}'</b> "
@@ -1253,6 +1264,7 @@ _MONITOR_PARAMETERS = {
                 threshold=kw["threshold"],
                 metricPerClass=kw["prediction_class"],
                 average=kw["average_method"],
+                quantile=kw["quantile"],
             ),
             description_builder=lambda **kw: (
                 "An anomaly in the value of the <b>'{metric}'</b> "
@@ -1279,6 +1291,7 @@ _MONITOR_PARAMETERS = {
                 threshold=kw["threshold"],
                 metricPerClass=kw["prediction_class"],
                 average=kw["average_method"],
+                quantile=kw["quantile"],
             ),
             description_builder=lambda **kw: (
                 "An anomaly in the value of the <b>'{metric}'</b> "
