@@ -1,4 +1,4 @@
-from typing import Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 from urllib.parse import urlencode
 
 from aporia.sdk.base import BaseAporiaResource
@@ -67,6 +67,17 @@ class Segment(BaseAporiaResource):
             self.__update_extended_data()
         return self.extended_data
 
+    def get_widget_values(self) -> List[Any]:
+        if self.extended_data is None:
+            self.__update_extended_data()
+
+        if (
+            self.extended_data["is_custom_segment"]
+            or self.extended_data["field"]["type"] != "numeric"
+        ):
+            return self.values
+        return self.values[:-1]
+
     def to_widget(self) -> Dict:
         if self.extended_data is None:
             self.__update_extended_data()
