@@ -163,6 +163,7 @@ class MetricConfiguration(MetricBaseModel):
     k: Optional[int] = None
     class_name: Optional[str] = None
     baseline: Optional[BaselineConfiguration] = None
+    quantile: Optional[float] = None
 
     def _get_metric(self) -> Union[MetricType, str]:
         if self.metric is MetricType.CUSTOM_METRIC:
@@ -194,6 +195,9 @@ class MetricConfiguration(MetricBaseModel):
 
     def _get_k(self) -> Optional[int]:
         return self.k
+    
+    def _get_quantile(self) -> Optional[float]:
+        return self.quantile
 
     def _get_class(self) -> Optional[str]:
         return self.class_name
@@ -330,6 +334,7 @@ class MetricOverrideConfiguration(BaseModel):
     k: Optional[int] = None
     class_name: Optional[str] = None
     baseline: Optional[BaselineConfiguration] = None
+    quantile: Optional[float] = None
 
     def _apply(self, original_metric: MetricConfiguration) -> MetricConfiguration:
         return MetricConfiguration(
@@ -341,4 +346,5 @@ class MetricOverrideConfiguration(BaseModel):
             k=self.k or original_metric.k,
             class_name=self.class_name or original_metric.class_name,
             baseline=self.baseline or original_metric.baseline,
+            quantile=self.quantile or original_metric.quantile,
         )
