@@ -30,6 +30,7 @@ class MetricWidgetDataOptionsAnnotations(BaseModel):
     baseline: Optional[BaselineConfiguration] = None
     threshold: Optional[float] = None
     metricAtK: Optional[int] = None
+    quantile: Optional[float] = None
     metricPerClass: Optional[str] = None
     average: Optional[AverageMethod] = None
     parameters: Optional[MetricParameters] = None
@@ -108,6 +109,7 @@ class MetricWidget(BaseWidget):
                             baseline=metric.baseline,
                             threshold=metric.threshold,
                             metricAtK=metric.k,
+                            quantile=metric.quantile,
                             metricPerClass=metric.class_name,
                             average=metric.average,
                             parameters=metric._get_parameters(),
@@ -166,6 +168,7 @@ class MetricWidget(BaseWidget):
                         baseline=metric._get_baseline(),
                         threshold=metric._get_threshold(),
                         metricAtK=metric._get_k(),
+                        quantile=metric._get_quantile(),
                         metricPerClass=metric._get_class(),
                         average=metric._get_average(),
                         parameters=metric._get_parameters(),
